@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-12-02'; # DATE
-our $VERSION = '1.31'; # VERSION
+our $DATE = '2016-01-20'; # DATE
+our $VERSION = '1.32'; # VERSION
 
 use 5.010001;
 use strict;
@@ -946,18 +946,19 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
             {
                 name => 'streaming',
                 before_all_tests => sub {
-                    write_text("$tempdir/infile1", "one\ntwo three\nfour\n");
-                    write_text("$tempdir/infile2", qq({}\n{"a":1}\n{"b":2,"c":3}\n{"d":4}\n));
-                    write_text("$tempdir/infile3", qq({}\n{\n));
-                    write_text("$tempdir/infile4", qq(1\n3\n5\n));
+                    write_text("$tempdir/infile-str", "one\ntwo three\nfour\n");
+                    write_text("$tempdir/infile-hash-json", qq({}\n{"a":1}\n{"b":2,"c":3}\n{"d":4}\n));
+                    write_text("$tempdir/infile-invalid-json", qq({}\n{\n));
+                    write_text("$tempdir/infile-int", qq(1\n3\n5\n));
+                    write_text("$tempdir/infile-invalid-int", qq(1\nx\n5\n));
                 },
                 tests => [
                     {
-                        tags        => ['streaming', 'streaming-input', 'fail1'],
+                        tags        => ['streaming', 'streaming-input'],
                         name        => "stream input (simple types)",
                         gen_args    => {url => '/Perinci/Examples/Stream/wc'},
                         inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
-                        argv        => ["$tempdir/infile1"],
+                        argv        => ["$tempdir/infile-str"],
                         stdout_like => qr/
                                              ^chars \s+ 19\n
                                              ^lines \s+ 3\n
@@ -965,11 +966,11 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                                          /mx,
                     },
                     {
-                        tags        => ['streaming', 'streaming-input', 'fail1'],
+                        tags        => ['streaming', 'streaming-input'],
                         name        => "stream input (json stream)",
                         gen_args    => {url => '/Perinci/Examples/Stream/wc_keys'},
                         inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
-                        argv        => ["$tempdir/infile2"],
+                        argv        => ["$tempdir/infile-hash-json"],
                         stdout_like => qr/^keys \s+ 4\n/mx,
                     },
                     {
@@ -977,21 +978,30 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         name        => 'stream input (json stream, error in record)',
                         gen_args    => {url => '/Perinci/Examples/Stream/wc_keys'},
                         inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
-                        argv        => ["$tempdir/infile3"],
+                        argv        => ["$tempdir/infile-invalid-json"],
                         exit_code => 200,
                     },
                     {
                         tags        => ['streaming', 'streaming-input', 'streaming-output'],
-                        name        => "stream output (simple types)",
+                        name        => "stream input+output (simple types)",
                         gen_args    => {url => '/Perinci/Examples/Stream/square_input'},
                         inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
-                        argv        => ["$tempdir/infile4"],
+                        argv        => ["$tempdir/infile-int"],
                         stdout_like => qr/
                                              ^1\n
                                              ^9\n
                                              ^25\n
                                          /mx,
                     },
+                    {
+                        tags        => ['streaming', 'streaming-input', 'streaming-output'],
+                        name        => "stream input+output (simple types, error in input record)",
+                        gen_args    => {url => '/Perinci/Examples/Stream/square_input'},
+                        inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
+                        argv        => ["$tempdir/infile-invalid-int"],
+                        exit_code => 25, # the result is 25, broken pipe?
+                        stderr_like => qr/fails validation/,
+                    },
                     {
                         tags        => ['streaming', 'streaming-output'],
                         name        => "stream output (json stream)",
@@ -1403,27 +1413,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.31 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-12-02.
-
-=head1 SEE ALSO
-
-Supported Perinci::CmdLine backends: L<Perinci::CmdLine::Inline>,
-L<Perinci::CmdLine::Lite>, L<Perinci::CmdLine::Classic>.
-
-=head1 ENVIRONMENT
-
-=head2 DEBUG => bool
-
-If set to 1, then temporary files (e.g. generated scripts for testing) will not
-be cleaned up, so you can inspect them.
-
-=head2 TEST_PERICMD_EXCLUDE_TAGS => str
-
-To set default for C<pericmd_ok()>'s C<exclude_tags> argument.
-
-=head2 TEST_PERICMD_INCLUDE_TAGS => str
-
-To set default for C<pericmd_ok()>'s C<include_tags> argument.
+This document describes version 1.32 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-01-20.
 
 =head1 FUNCTIONS
 
@@ -1500,6 +1490,21 @@ that contains extra information.
 
 Return value:  (any)
 
+=head1 ENVIRONMENT
+
+=head2 DEBUG => bool
+
+If set to 1, then temporary files (e.g. generated scripts for testing) will not
+be cleaned up, so you can inspect them.
+
+=head2 TEST_PERICMD_EXCLUDE_TAGS => str
+
+To set default for C<pericmd_ok()>'s C<exclude_tags> argument.
+
+=head2 TEST_PERICMD_INCLUDE_TAGS => str
+
+To set default for C<pericmd_ok()>'s C<include_tags> argument.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Test-Perinci-CmdLine>.
@@ -1516,13 +1521,18 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+Supported Perinci::CmdLine backends: L<Perinci::CmdLine::Inline>,
+L<Perinci::CmdLine::Lite>, L<Perinci::CmdLine::Classic>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
